@@ -13,7 +13,7 @@
 #'
 #' @details
 #' Details are described in
-#' \url{https://github.com/psychbruce/ChineseNames}
+#' \url{https://psychbruce.github.io/ChineseNames/}
 #'
 #' @note
 #' This database does not contain any individual-level information
@@ -26,31 +26,42 @@
 #' originally obtained from the National Citizen Identity Information Center (NCIIC) of China in 2008.
 #'
 #' @section Citation:
-#' Bao, H.-W.-S. (2021). ChineseNames: Chinese Name Database 1930-2008.
-#' R package version 1.1.1.
+#' Bao, H.-W.-S. (2023). ChineseNames: Chinese Name Database 1930-2008.
+#' R package version 2023.8.
 #' \url{https://CRAN.R-project.org/package=ChineseNames}
 #'
 #' Bao, H.-W.-S., Cai, H., Jing, Y., & Wang, J. (2021).
 #' Novel evidence for the increasing prevalence of unique names in China:
-#' A reply to Ogihara (2020). \emph{Frontiers in Psychology, 12}, 731244.
-#' \url{https://www.frontiersin.org/articles/10.3389/fpsyg.2021.731244/full}
+#' A reply to Ogihara. \emph{Frontiers in Psychology, 12}, 731244.
+#' \doi{10.3389/fpsyg.2021.731244}
 #'
 #' @docType package
 #' @name ChineseNames
 NULL
 
 
-.onAttach=function(libname, pkgname) {
-  packageStartupMessage(
-    "\nTo use the `ChineseNames` package in publications, please cite:\n\n",
-    "Bao, H.-W.-S. (2021). ",
-    "ChineseNames: Chinese Name Database 1930-2008. ",
-    "R package version 1.1.1. ",
-    "https://CRAN.R-project.org/package=ChineseNames\n\n",
-    "Other references:\n\n",
-    "Bao, H.-W.-S., Cai, H., Jing, Y., & Wang, J. (2021). ",
-    "Novel evidence for the increasing prevalence of unique names in China: ",
-    "A reply to Ogihara (2020). Frontiers in Psychology, 12, 731244.\n")
+.onAttach = function(libname, pkgname) {
+  inst.ver = as.character(utils::packageVersion("ChineseNames"))
+  packageStartupMessage(glue::glue_col("
+
+  {magenta ChineseNames (v{inst.ver})}
+  {blue Chinese Name Database 1930-2008}
+
+  {magenta Online documentation:}
+  {underline https://psychbruce.github.io/ChineseNames}
+
+  {magenta To use this package in publications, please cite:}
+
+  "),
+  "\n",
+  "Bao, H.-W.-S. (2023). ",
+  "ChineseNames: Chinese Name Database 1930-2008. ",
+  "R package version 2023.8. ",
+  "https://CRAN.R-project.org/package=ChineseNames\n",
+  "\n",
+  "Bao, H.-W.-S., Cai, H., Jing, Y., & Wang, J. (2021). ",
+  "Novel evidence for the increasing prevalence of unique names in China: ",
+  "A reply to Ogihara. Frontiers in Psychology, 12, 731244.\n")
 }
 
 
@@ -71,7 +82,7 @@ NULL
 #'   \item{\code{ppm.1930_2008}}{proportion in population (ppm = parts per million)}
 #'   \item{\code{surname.uniqueness}}{surname uniqueness}
 #' }
-#' @details \url{https://github.com/psychbruce/ChineseNames}
+#' @details \url{https://psychbruce.github.io/ChineseNames/}
 NULL
 
 
@@ -97,42 +108,42 @@ NULL
 #'   \item{\code{name.warmth}}{name warmth/morality (based on subjective ratings from 10 raters, ICC = 0.774)}
 #'   \item{\code{name.competence}}{name competence/assertiveness (based on subjective ratings from 10 raters, ICC = 0.712)}
 #' }
-#' @details \url{https://github.com/psychbruce/ChineseNames}
+#' @details \url{https://psychbruce.github.io/ChineseNames/}
 NULL
 
 
 #' Population statistics for the Chinese name database.
 #' @name population
 #' @usage data(population)
-#' @details \url{https://github.com/psychbruce/ChineseNames}
+#' @details \url{https://psychbruce.github.io/ChineseNames/}
 NULL
 
 
 #' Top 1,000 given names in 31 Chinese mainland provinces.
 #' @name top1000name.prov
 #' @usage data(top1000name.prov)
-#' @details \url{https://github.com/psychbruce/ChineseNames}
+#' @details \url{https://psychbruce.github.io/ChineseNames/}
 NULL
 
 
 #' Top 100 given names in 6 birth cohorts.
 #' @name top100name.year
 #' @usage data(top100name.year)
-#' @details \url{https://github.com/psychbruce/ChineseNames}
+#' @details \url{https://psychbruce.github.io/ChineseNames/}
 NULL
 
 
 #' Top 50 given-name characters in 6 birth cohorts.
 #' @name top50char.year
 #' @usage data(top50char.year)
-#' @details \url{https://github.com/psychbruce/ChineseNames}
+#' @details \url{https://psychbruce.github.io/ChineseNames/}
 NULL
 
 
 #### Functions ####
 
 
-`%>%`=dplyr::`%>%`
+`%>%` = dplyr::`%>%`
 
 
 #' Compute multiple features of surnames and given names.
@@ -179,7 +190,7 @@ NULL
 #'   \item \code{NC}: name competence (1~5).
 #' }
 #'
-#' For details, see \url{https://github.com/psychbruce/ChineseNames}
+#' For details, see \url{https://psychbruce.github.io/ChineseNames/}
 #' @param NU.approx Whether to \emph{approximately} compute name-character uniqueness (NU)
 #' using \emph{the nearest two birth cohorts with relative weights}
 #' (which would be more precise than just using a single birth cohort).
@@ -197,204 +208,206 @@ NULL
 #' \code{name1}, \code{name2}, and \code{name3} (given-name characters).
 #'
 #' @note
-#' For details and examples, see \url{https://github.com/psychbruce/ChineseNames}
+#' For details and examples, see \url{https://psychbruce.github.io/ChineseNames/}
 #'
 #' @section Citation:
-#' Bao, H.-W.-S. (2021). ChineseNames: Chinese Name Database 1930-2008.
-#' R package version 1.1.1.
+#' Bao, H.-W.-S. (2023). ChineseNames: Chinese Name Database 1930-2008.
+#' R package version 2023.8.
 #' \url{https://CRAN.R-project.org/package=ChineseNames}
 #'
 #' Bao, H.-W.-S., Cai, H., Jing, Y., & Wang, J. (2021).
 #' Novel evidence for the increasing prevalence of unique names in China:
-#' A reply to Ogihara (2020). \emph{Frontiers in Psychology, 12}, 731244.
-#' \url{https://www.frontiersin.org/articles/10.3389/fpsyg.2021.731244/full}
+#' A reply to Ogihara. \emph{Frontiers in Psychology, 12}, 731244.
+#' \doi{10.3389/fpsyg.2021.731244}
 #'
 #' @examples
 #' ## Prepare ##
-#' sn=familyname$surname[1:12]
-#' gn=c(top100name.year$name.all.1960[1:6],
-#'      top100name.year$name.all.2000[1:6],
-#'      top100name.year$name.all.1960[95:100],
-#'      top100name.year$name.all.2000[95:100])
-#' demodata=data.frame(name=paste0(sn, gn),
-#'                     birth=c(1960:1965, 2000:2005,
-#'                             1960:1965, 2000:2005))
-#' # View(demodata)
+#' sn = familyname$surname[1:12]
+#' gn = c(top100name.year$name.all.1960[1:6],
+#'        top100name.year$name.all.2000[1:6],
+#'        top100name.year$name.all.1960[95:100],
+#'        top100name.year$name.all.2000[95:100])
+#' demodata = data.frame(name=paste0(sn, gn),
+#'                       birth=c(1960:1965, 2000:2005,
+#'                               1960:1965, 2000:2005))
+#' demodata
 #'
 #' ## Compute ##
-#' newdata=compute_name_index(demodata,
-#'                            var.fullname="name",
-#'                            var.birthyear="birth")
-#' # View(newdata)
+#' newdata = compute_name_index(demodata,
+#'                              var.fullname="name",
+#'                              var.birthyear="birth")
+#' newdata
 #'
 #' @import data.table
 #' @importFrom bruceR dtime Print MEAN LOOKUP
 #' @export
-compute_name_index=function(data=NULL,
-                            var.fullname=NULL,
-                            var.surname=NULL,
-                            var.givenname=NULL,
-                            var.birthyear=NULL,
-                            name=NA, birth=NA,
-                            index=c("NLen",
-                                    "SNU", "SNI",
-                                    "NU", "CCU", "NG",
-                                    "NV", "NW", "NC"),
-                            NU.approx=TRUE,
-                            digits=4,
-                            return.namechar=TRUE,
-                            return.all=FALSE) {
+compute_name_index = function(
+    data=NULL,
+    var.fullname=NULL,
+    var.surname=NULL,
+    var.givenname=NULL,
+    var.birthyear=NULL,
+    name=NA, birth=NA,
+    index=c("NLen",
+            "SNU", "SNI",
+            "NU", "CCU", "NG",
+            "NV", "NW", "NC"),
+    NU.approx=TRUE,
+    digits=4,
+    return.namechar=TRUE,
+    return.all=FALSE
+) {
   ## Prepare ##
 
-  if(!is.null(data)) log=(nrow(data)>=1000) else log=FALSE
-  t0=Sys.time()
+  if(!is.null(data)) log = (nrow(data)>=1000) else log = FALSE
+  t0 = Sys.time()
 
-  familyname=ChineseNames::familyname
-  givenname=ChineseNames::givenname
+  familyname = ChineseNames::familyname
+  givenname = ChineseNames::givenname
 
-  fuxing=familyname[familyname$compound==1, "surname"]
-  ref0=data.table(char=givenname$character, code=0, ppm=givenname$name.ppm)
-  ref1=data.table(char=givenname$character, code=1, ppm=givenname$ppm.1930_1959)
-  ref2=data.table(char=givenname$character, code=2, ppm=givenname$ppm.1960_1969)
-  ref3=data.table(char=givenname$character, code=3, ppm=givenname$ppm.1970_1979)
-  ref4=data.table(char=givenname$character, code=4, ppm=givenname$ppm.1980_1989)
-  ref5=data.table(char=givenname$character, code=5, ppm=givenname$ppm.1990_1999)
-  ref6=data.table(char=givenname$character, code=6, ppm=givenname$ppm.2000_2008)
-  ref.long=rbind(ref0, ref1, ref2, ref3, ref4, ref5, ref6)
+  fuxing = familyname[familyname$compound==1, "surname"]
+  ref0 = data.table(char=givenname$character, code=0, ppm=givenname$name.ppm)
+  ref1 = data.table(char=givenname$character, code=1, ppm=givenname$ppm.1930_1959)
+  ref2 = data.table(char=givenname$character, code=2, ppm=givenname$ppm.1960_1969)
+  ref3 = data.table(char=givenname$character, code=3, ppm=givenname$ppm.1970_1979)
+  ref4 = data.table(char=givenname$character, code=4, ppm=givenname$ppm.1980_1989)
+  ref5 = data.table(char=givenname$character, code=5, ppm=givenname$ppm.1990_1999)
+  ref6 = data.table(char=givenname$character, code=6, ppm=givenname$ppm.2000_2008)
+  ref.long = rbind(ref0, ref1, ref2, ref3, ref4, ref5, ref6)
 
   ## Initialize ##
 
-  `.`=NULL
-  NLen=SNU=SNI=NU=CCU=NG=NV=NW=NC=NULL
-  fx=sur.name=given.name=full.name=name0=name1=name2=name3=NULL
+  `.` = NULL
+  NLen = SNU = SNI = NU = CCU = NG = NV = NW = NC = NULL
+  fx = sur.name = given.name = full.name = name0 = name1 = name2 = name3 = NULL
 
   ## Main ##
 
   if(is.na(name)==FALSE) {
-    data=data.frame(name=name, birth=birth)
-    var.fullname="name"
-    var.birthyear="birth"
+    data = data.frame(name=name, birth=birth)
+    var.fullname = "name"
+    var.birthyear = "birth"
   }
   if(is.null(data))
     stop("Please input your data.")
   if(is.null(var.fullname) & is.null(var.surname) & is.null(var.givenname))
     stop("Please input variable(s) of full/family/given names.")
 
-  data=as.data.frame(data)
+  data = as.data.frame(data)
   if(!is.null(var.fullname)) {
-    d=data.table(full.name=data[[var.fullname]])
-    d[,NLen:=nchar(full.name)]
-    d[,sur.name:=substr(full.name, 1,
-                        ifelse((substr(full.name, 1, 2) %in% fuxing) & NLen>2,
-                               2, 1))]
-    d[,given.name:=substr(full.name, nchar(sur.name)+1, NLen)]
+    d = data.table(full.name=data[[var.fullname]])
+    d[, NLen := nchar(full.name)]
+    d[, sur.name := substr(full.name, 1,
+                           ifelse((substr(full.name, 1, 2) %in% fuxing) & NLen>2,
+                                  2, 1))]
+    d[, given.name := substr(full.name, nchar(sur.name)+1, NLen)]
   } else {
     if(!is.null(var.surname) & !is.null(var.givenname)) {
-      d=data.table(sur.name=data[[var.surname]], given.name=data[[var.givenname]])
+      d = data.table(sur.name=data[[var.surname]], given.name=data[[var.givenname]])
     } else {
       if(!is.null(var.surname))
-        d=data.table(sur.name=data[[var.surname]], given.name="")
+        d = data.table(sur.name=data[[var.surname]], given.name="")
       if(!is.null(var.givenname))
-        d=data.table(sur.name="", given.name=data[[var.givenname]])
+        d = data.table(sur.name="", given.name=data[[var.givenname]])
     }
-    d[,full.name:=paste0(sur.name, given.name)]
-    d[,NLen:=nchar(full.name)]
+    d[, full.name := paste0(sur.name, given.name)]
+    d[, NLen := nchar(full.name)]
   }
-  d[,name0:=sur.name]
-  d[,name1:=substr(given.name, 1, 1)]
-  d[,name2:=substr(given.name, 2, 2)]
-  d[,name3:=substr(given.name, 3, 3)]
+  d[, name0 := sur.name]
+  d[, name1 := substr(given.name, 1, 1)]
+  d[, name2 := substr(given.name, 2, 2)]
+  d[, name3 := substr(given.name, 3, 3)]
 
   if(!is.null(var.birthyear))
-    d=cbind(d, year=data[[var.birthyear]])
+    d = cbind(d, year=data[[var.birthyear]])
   else
-    d=cbind(d, year=NA)
+    d = cbind(d, year=NA)
 
-  d=d[,.(name0, name1, name2, name3, year, NLen)]
+  d = d[,.(name0, name1, name2, name3, year, NLen)]
 
   if(log) Print("Data preprocessed ({dtime(t0)}).")
 
   if("SNU" %in% index) {
-    t0=Sys.time()
-    d[,SNU:=LOOKUP(d, "name0", familyname, "surname", "surname.uniqueness", return="new.value") %>% round(digits)]
+    t0 = Sys.time()
+    d[, SNU := LOOKUP(d, "name0", familyname, "surname", "surname.uniqueness", return="new.value") %>% round(digits)]
     if(log) Print("SNU computed ({dtime(t0)}).")
   }
 
   if("SNI" %in% index) {
-    t0=Sys.time()
-    d[,SNI:=LOOKUP(d, "name0", familyname, "surname", "initial.rank", return="new.value")]
+    t0 = Sys.time()
+    d[, SNI := LOOKUP(d, "name0", familyname, "surname", "initial.rank", return="new.value")]
     if(log) Print("SNI computed ({dtime(t0)}).")
   }
 
   if("NU" %in% index) {
-    t0=Sys.time()
-    d[,`:=`(
-      nu1=compute_NU_char(d, ref.long, "name1", "year", NU.approx),
-      nu2=compute_NU_char(d, ref.long, "name2", "year", NU.approx),
-      nu3=compute_NU_char(d, ref.long, "name3", "year", NU.approx)
+    t0 = Sys.time()
+    d[, `:=`(
+      nu1 = compute_NU_char(d, ref.long, "name1", "year", NU.approx),
+      nu2 = compute_NU_char(d, ref.long, "name2", "year", NU.approx),
+      nu3 = compute_NU_char(d, ref.long, "name3", "year", NU.approx)
     )]
-    d[,NU:=MEAN(d, "nu", 1:3) %>% round(digits)]
+    d[, NU := MEAN(d, "nu", 1:3) %>% round(digits)]
     if(log) Print("NU computed ({dtime(t0)}).")
   }
 
   if("CCU" %in% index) {
-    t0=Sys.time()
-    d[,`:=`(
-      ccu1=LOOKUP(d, "name1", givenname, "character", "corpus.uniqueness", return="new.value"),
-      ccu2=LOOKUP(d, "name2", givenname, "character", "corpus.uniqueness", return="new.value"),
-      ccu3=LOOKUP(d, "name3", givenname, "character", "corpus.uniqueness", return="new.value")
+    t0 = Sys.time()
+    d[, `:=`(
+      ccu1 = LOOKUP(d, "name1", givenname, "character", "corpus.uniqueness", return="new.value"),
+      ccu2 = LOOKUP(d, "name2", givenname, "character", "corpus.uniqueness", return="new.value"),
+      ccu3 = LOOKUP(d, "name3", givenname, "character", "corpus.uniqueness", return="new.value")
     )]
-    d[,CCU:=MEAN(d, "ccu", 1:3) %>% round(digits)]
+    d[, CCU := MEAN(d, "ccu", 1:3) %>% round(digits)]
     if(log) Print("CCU computed ({dtime(t0)}).")
   }
 
   if("NG" %in% index) {
-    t0=Sys.time()
-    d[,`:=`(
-      ng1=LOOKUP(d, "name1", givenname, "character", "name.gender", return="new.value"),
-      ng2=LOOKUP(d, "name2", givenname, "character", "name.gender", return="new.value"),
-      ng3=LOOKUP(d, "name3", givenname, "character", "name.gender", return="new.value")
+    t0 = Sys.time()
+    d[, `:=`(
+      ng1 = LOOKUP(d, "name1", givenname, "character", "name.gender", return="new.value"),
+      ng2 = LOOKUP(d, "name2", givenname, "character", "name.gender", return="new.value"),
+      ng3 = LOOKUP(d, "name3", givenname, "character", "name.gender", return="new.value")
     )]
-    d[,NG:=MEAN(d, "ng", 1:3) %>% round(digits)]
+    d[, NG := MEAN(d, "ng", 1:3) %>% round(digits)]
     if(log) Print("NG computed ({dtime(t0)}).")
   }
 
   if("NV" %in% index) {
-    t0=Sys.time()
-    d[,`:=`(
-      nv1=LOOKUP(d, "name1", givenname, "character", "name.valence", return="new.value"),
-      nv2=LOOKUP(d, "name2", givenname, "character", "name.valence", return="new.value"),
-      nv3=LOOKUP(d, "name3", givenname, "character", "name.valence", return="new.value")
+    t0 = Sys.time()
+    d[, `:=`(
+      nv1 = LOOKUP(d, "name1", givenname, "character", "name.valence", return="new.value"),
+      nv2 = LOOKUP(d, "name2", givenname, "character", "name.valence", return="new.value"),
+      nv3 = LOOKUP(d, "name3", givenname, "character", "name.valence", return="new.value")
     )]
-    d[,NV:=MEAN(d, "nv", 1:3) %>% round(digits)]
+    d[, NV := MEAN(d, "nv", 1:3) %>% round(digits)]
     if(log) Print("NV computed ({dtime(t0)}).")
   }
 
   if("NW" %in% index) {
-    t0=Sys.time()
-    d[,`:=`(
-      nw1=LOOKUP(d, "name1", givenname, "character", "name.warmth", return="new.value"),
-      nw2=LOOKUP(d, "name2", givenname, "character", "name.warmth", return="new.value"),
-      nw3=LOOKUP(d, "name3", givenname, "character", "name.warmth", return="new.value")
+    t0 = Sys.time()
+    d[, `:=`(
+      nw1 = LOOKUP(d, "name1", givenname, "character", "name.warmth", return="new.value"),
+      nw2 = LOOKUP(d, "name2", givenname, "character", "name.warmth", return="new.value"),
+      nw3 = LOOKUP(d, "name3", givenname, "character", "name.warmth", return="new.value")
     )]
-    d[,NW:=MEAN(d, "nw", 1:3) %>% round(digits)]
+    d[, NW := MEAN(d, "nw", 1:3) %>% round(digits)]
     if(log) Print("NW computed ({dtime(t0)}).")
   }
 
   if("NC" %in% index) {
-    t0=Sys.time()
-    d[,`:=`(
-      nc1=LOOKUP(d, "name1", givenname, "character", "name.competence", return="new.value"),
-      nc2=LOOKUP(d, "name2", givenname, "character", "name.competence", return="new.value"),
-      nc3=LOOKUP(d, "name3", givenname, "character", "name.competence", return="new.value")
+    t0 = Sys.time()
+    d[, `:=`(
+      nc1 = LOOKUP(d, "name1", givenname, "character", "name.competence", return="new.value"),
+      nc2 = LOOKUP(d, "name2", givenname, "character", "name.competence", return="new.value"),
+      nc3 = LOOKUP(d, "name3", givenname, "character", "name.competence", return="new.value")
     )]
-    d[,NC:=MEAN(d, "nc", 1:3) %>% round(digits)]
+    d[, NC := MEAN(d, "nc", 1:3) %>% round(digits)]
     if(log) Print("NC computed ({dtime(t0)}).")
   }
 
   if(return.namechar)
-    data=cbind(data, d[,.(name0, name1, name2, name3)])
-  data.new=cbind(data, as.data.frame(d)[index]) %>% as.data.table()
+    data = cbind(data, d[,.(name0, name1, name2, name3)])
+  data.new = cbind(data, as.data.frame(d)[index]) %>% as.data.table()
   if(return.all)
     return(d)
   else
@@ -403,33 +416,33 @@ compute_name_index=function(data=NULL,
 
 
 #' @importFrom bruceR LOOKUP
-compute_NU_char=function(data, ref.long, var.char, var.year=NULL, approx=TRUE) {
-  ppm1=ppm2=weight1=weight2=NULL
+compute_NU_char = function(data, ref.long, var.char, var.year=NULL, approx=TRUE) {
+  ppm1 = ppm2 = weight1 = weight2 = NULL
   if(is.null(var.year)) {
-    ppm=LOOKUP(data, var.char,
-               ChineseNames::givenname, "character", "name.ppm",
-               return="new.value")
+    ppm = LOOKUP(data, var.char,
+                 ChineseNames::givenname, "character", "name.ppm",
+                 return="new.value")
   } else {
-    d=as.data.frame(data)[c(var.char, var.year)]
-    names(d)=c("char", "year")
-    d$code=car::recode(
+    d = as.data.frame(data)[c(var.char, var.year)]
+    names(d) = c("char", "year")
+    d$code = car::recode(
       d$year, "lo:1929=1; 1930:1959=1; 1960:1969=2; 1970:1979=3; 1980:1989=4; 1990:1999=5; 2000:2009=6; else=0")
-    d$code1=car::recode(
+    d$code1 = car::recode(
       d$year, "lo:1954=1; 1955:1964=1; 1965:1974=2; 1975:1984=3; 1985:1994=4; 1995:2004=5; 2005:2009=6; else=0")
-    d$code2=car::recode(
+    d$code2 = car::recode(
       d$year, "lo:1954=1; 1955:1964=2; 1965:1974=3; 1975:1984=4; 1985:1994=5; 1995:2004=6; 2005:2009=6; else=0")
-    d$weight1=5-(d$year%%10)
-    d$weight1=ifelse(d$weight1>0, d$weight1, 10+d$weight1)
-    d$weight1=ifelse(is.na(d$weight1), 5, d$weight1)
-    d$weight2=10-d$weight1
+    d$weight1 = 5 - (d$year %% 10)
+    d$weight1 = ifelse(d$weight1 > 0, d$weight1, 10 + d$weight1)
+    d$weight1 = ifelse(is.na(d$weight1), 5, d$weight1)
+    d$weight2 = 10 - d$weight1
     if(approx==FALSE) {
-      d$ppm=LOOKUP(d, c("char", "code"), ref.long, c("char", "code"), "ppm", return="new.value")
+      d$ppm = LOOKUP(d, c("char", "code"), ref.long, c("char", "code"), "ppm", return="new.value")
     } else {
-      d$ppm1=LOOKUP(d, c("char", "code1"), ref.long, c("char", "code"), "ppm", return="new.value")
-      d$ppm2=LOOKUP(d, c("char", "code2"), ref.long, c("char", "code"), "ppm", return="new.value")
-      d=dplyr::mutate(d, ppm=(ppm1*weight1+ppm2*weight2)/10)
+      d$ppm1 = LOOKUP(d, c("char", "code1"), ref.long, c("char", "code"), "ppm", return="new.value")
+      d$ppm2 = LOOKUP(d, c("char", "code2"), ref.long, c("char", "code"), "ppm", return="new.value")
+      d = dplyr::mutate(d, ppm=(ppm1*weight1+ppm2*weight2)/10)
     }
   }
-  d$ppm=ifelse(is.na(d$ppm) & !is.na(d$char) & d$char!="", 0, d$ppm)
-  return(as.numeric( -log10((d$ppm+1)/10^6) ))
+  d$ppm = ifelse(is.na(d$ppm) & !is.na(d$char) & d$char != "", 0, d$ppm)
+  return(as.numeric( -log10((d$ppm+1) / 10^6) ))
 }
